/*
 * Copyright 2016 OpenMarket Ltd
 * Copyright 2017 Vector Creations Ltd
 * Copyright 2018 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.vector.fragments;

import android.os.Bundle;
import android.text.TextUtils;
import android.widget.Filter;

import androidx.appcompat.widget.SearchView;
import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import org.matrix.androidsdk.rest.model.group.GroupUser;

import butterknife.BindView;
import im.vector.R;
import im.vector.adapters.GroupDetailsPeopleAdapter;
import im.vector.util.GroupUtils;
import im.vector.view.EmptyViewItemDecoration;
import im.vector.view.SimpleDividerItemDecoration;

public class GroupDetailsPeopleFragment extends GroupDetailsBaseFragment {
    @BindView(R.id.people_recyclerview)
    RecyclerView mRecycler;

    @BindView(R.id.people_search_view)
    SearchView mSearchView;

    private GroupDetailsPeopleAdapter mAdapter;
    private String mCurrentFilter;

    @Override
    public int getLayoutResId() {
        return R.layout.fragment_group_details_people;
    }

    @Override
    public void onResume() {
        super.onResume();
        refreshViews();
    }

    @Override
    public void onActivityCreated(final Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        mCurrentFilter = mSearchView.getQuery().toString();
        mAdapter.onFilterDone(mCurrentFilter);
    }
    /*
     * *********************************************************************************************
     * UI management
     * *********************************************************************************************
     */

    /**
     * Prepare views
     */
    @Override
    protected void initViews() {
        int margin = (int) getResources().getDimension(R.dimen.item_decoration_left_margin);
        mRecycler.setLayoutManager(new LinearLayoutManager(getActivity(), RecyclerView.VERTICAL, false));
        mRecycler.addItemDecoration(new SimpleDividerItemDecoration(getActivity(), DividerItemDecoration.VERTICAL, margin));
        mRecycler.addItemDecoration(new EmptyViewItemDecoration(getActivity(), DividerItemDecoration.VERTICAL, 40, 16, 14));
        mAdapter = new GroupDetailsPeopleAdapter(getActivity(), new GroupDetailsPeopleAdapter.OnSelectUserListener() {
            @Override
            public void onSelectItem(GroupUser user, int position) {
                GroupUtils.openGroupUserPage(mActivity, mSession, user);
            }
        });
        mRecycler.setAdapter(mAdapter);

        mSearchView.setOnQueryTextListener(new SearchView.OnQueryTextListener() {
            @Override
            public boolean onQueryTextSubmit(String query) {
                return true;
            }

            @Override
            public boolean onQueryTextChange(final String newText) {
                if (!TextUtils.equals(mCurrentFilter, newText)) {
                    mAdapter.getFilter().filter(newText, new Filter.FilterListener() {
                        @Override
                        public void onFilterComplete(int count) {
                            mCurrentFilter = newText;
                        }
                    });
                }
                return true;
            }
        });

        mSearchView.setMaxWidth(Integer.MAX_VALUE);
        mSearchView.setQueryHint(getString(R.string.filter_group_members));
        mSearchView.setFocusable(false);
        mSearchView.setIconifiedByDefault(false);
        mSearchView.clearFocus();
    }

    @Override
    public void refreshViews() {
        if (!isAdded()) {
            return;
        }

        mAdapter.setJoinedGroupUsers(mActivity.getGroup().getGroupUsers().getUsers());
        mAdapter.setInvitedGroupUsers(mActivity.getGroup().getInvitedGroupUsers().getUsers());
    }
}
